abacusai.code_autocomplete_response — AbacusAI documentation

# abacusai.code_autocomplete_response

## Classes

`CodeAutocompleteResponse` | A autocomplete response from an LLM

## Module Contents

class abacusai.code_autocomplete_response.CodeAutocompleteResponse(client, autocompleteResponse=None, showAutocomplete=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A autocomplete response from an LLM

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - autocompleteResponse (str) – autocomplete code

    - showAutocomplete (bool) – Whether to show autocomplete in the client

  autocomplete_response = None
  show_autocomplete = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict